@@ -21,6 +21,31 @@ sub startup :Test(startup) {
     ); # just get the ball rolling
 
     diag "Running on $AnyEvent::MODEL";
+
+    do {
+        no warnings 'once'; ## no critic (TestingAndDebugging::ProhibitNoWarnings)
+        $EV::DIED = sub {
+            unless($@ =~ /bad apple/) {
+                warn $@;
+            }
+        };
+        $Event::DIED = sub {
+            my ( undef, $error ) = @_;
+
+            unless($error =~ /bad apple/ || $error eq '?') {
+                warn $error;
+            }
+        };
+
+        eval { Glib->install_exception_handler(sub {
+            my ( $error ) = @_;
+
+            unless($error =~ /bad apple/) {
+                warn $error;
+            }
+            return 1;
+        })};
+    };
 }
 
 sub test_simple_app :Test(3) {
@@ -528,4 +553,30 @@ sub test_infinite_request_shutdown :Test {
     };
 }
 
+sub test_three_element_delayed_response :Test(3) {
+    my $app = sub {
+        return sub {
+            my ( $respond ) = @_;
+
+            $respond->([
+                200,
+                [ 'Content-Type' => 'text/plain' ],
+                ['OK']
+            ]);
+        };
+    };
+
+    test_psgi $app, sub {
+        my ( $cb ) = @_;
+
+        my $res = $cb->(GET '/');
+        $res->on_content_received(sub{
+            is $res->code, 200, 'Status code should match';
+            is $res->content_type, 'text/plain', 'Content-Type header should match';
+            is $res->content, 'OK', 'Content should match';
+        });
+        $res->recv;
+    };
+}
+
 1;
